@@ -5,118 +5,14 @@ import warnings
 #
 #*****************************************************************************
 #
-class _CommonTools():
-    def __init__(self, awrde):#----------------------------------------------------------
-        self.awrde = awrde
-        #
-    @property
-    def get_all_active_measurements(self) -> list:#------------------------------------
-        '''returns a list of all the active measurements from all the graphs in the project'''
-        active_meas_list = list()
-        for gr in self.awrde.Project.Graphs:
-            for meas in gr.Measurements:
-                active_meas_list.append(meas.Name)
-            #end for
-        #end for
-        return active_meas_list
-        #    
-#
-#*****************************************************************************
-#
-class _Document_Methods():
-    def __init__(self, document: object,):#--------------------------------------------
-        self._document = document
-        #
-    def add_wire(self, start_xy: tuple, end_xy: tuple):
-        '''
-        Adds a wire to a schematic or system diagram
-        
-        Parameters
-        ---------- 
-        start_xy: tuple
-              Start x,y cooridnates of the wire segment
-              
-        end_xy: tuple
-              End x,y cooridnates of the wire segment     
-        '''
-        try:
-            self._document.Wires.Add(int(start_xy[0]), int(start_xy[1]), int(end_xy[0]), int(end_xy[1]))
-        except:
-            warnings.warn('Could not add wire to document')
-        #end try
-        #
-    def remove_wire(self, start_xy: tuple, end_xy: tuple):
-        '''
-        Removes a wire from a schematic or system diagram
-        
-        Parameters
-        ---------- 
-        start_xy: tuple
-              Start x,y cooridnates of the wire segment
-              
-        end_xy: tuple
-              End x,y cooridnates of the wire segment     
-        '''
-        num_wires = self._document.Wires.Count
-        wire_removed = False
-        for wire_idx in range(num_wires):
-            wire_start_x = self._document.Wires.Item(wire_idx+1).x1
-            wire_start_y = self._document.Wires.Item(wire_idx+1).y1
-            wire_end_x = self._document.Wires.Item(wire_idx+1).x2
-            wire_end_y = self._document.Wires.Item(wire_idx+1).y2
-            found_it = True
-            if wire_start_x != start_xy[0]:
-                found_it = False
-            if wire_start_y != start_xy[1]:
-                found_it = False
-            if wire_end_x != end_xy[0]:
-                found_it = False
-            if wire_end_y != end_xy[1]:
-                found_it = False
-            #end if
-            if found_it:
-                self._document.Wires.Remove(wire_idx+1)
-                wire_removed = True
-                break
-            #end if
-        #end for
-        if not wire_removed:
-            warnings.warn('Wire could not be removed')
-        #end if
-        #
-    @property
-    def wire_segments_dict(self) -> dict:
-        '''
-        returns dictionary of wire segments
-        
-        Returns
-        ---------- 
-        wire_segment_dict:
-             keys = wire segment index
-             values = tuple (start x, start y, end x, end y)
-
-        '''
-        wire_segment_dict = dict()
-        num_wires = self._document.Wires.Count
-        for wire_idx in range(num_wires):
-            wire_start_x = self._document.Wires.Item(wire_idx+1).x1
-            wire_start_y = self._document.Wires.Item(wire_idx+1).y1
-            wire_end_x = self._document.Wires.Item(wire_idx+1).x2
-            wire_end_y = self._document.Wires.Item(wire_idx+1).y2
-            wire_segment_dict[wire_idx] = (wire_start_x, wire_start_y, wire_end_x, wire_end_y)
-        #end for
-        return wire_segment_dict
-        #
-#
-#*****************************************************************************
-#
 class _Parameter():
+
     def __init__(self, parameter, document_type):
         self._parameter = parameter
         self._document_type = document_type
 
     @property
-    def name(self) -> str:
+    def name(self):
         return self._parameter.Name
 
     @property
@@ -128,7 +24,7 @@ class _Parameter():
 
     @value.setter
     def value(self, value):
-        if not (isinstance(value, float) or isinstance(value, int)):
+        if not isinstance(value, float) or not isinstance(value, int):
             raise RuntimeError('value must be float or int type')
         #end if        
         if self._document_type == 'System':
@@ -137,7 +33,7 @@ class _Parameter():
         self._parameter.ValueAsDouble = value
 
     @property
-    def value_str(self) -> str:
+    def value_str(self):
         return self._parameter.ValueAsString
 
     @value_str.setter
@@ -146,68 +42,10 @@ class _Parameter():
             raise RuntimeError('value_str must be string type')
         #end if
         self._parameter.ValueAsString = value_str
-        
-    @property
-    def optimize_enabled(self) -> bool:#----------------------------------------------
-        '''returns Optimize enabled state '''
-        return self._parameter.Optimize
-        #
-    @optimize_enabled.setter
-    def optimize_enabled(self, enabled: bool):#--------------------------------------
-        '''sets Optimize enabled state '''
-        self._parameter.Optimize = enabled
-        #
-    @property
-    def constrain(self) -> bool:#-------------------------------------------------------
-        '''returns Contrain enabled state '''
-        return self._parameter.Constrain
-        #
-    @constrain.setter
-    def constrain(self, enabled: bool):#----------------------------------------------------
-        '''sets Contrain enabled state '''
-        self._parameter.Constrain = enabled
-        #
-    @property
-    def lower_constraint(self) -> float:#-------------------------------------------------
-        ''' returns LowerContraint value'''
-        return self._parameter.LowerConstraint
-        #
-    @lower_constraint.setter
-    def lower_constraint(self, lower_contraint_value:float):#-----------------------------
-        ''' sets LowerContraint value'''
-        if not isinstance(lower_contraint_value, float) and  not isinstance(lower_contraint_value, int):
-            raise TypeError('lower_contraint_value must be float or int')
-        #end if
-        self._parameter.LowerConstraint = lower_contraint_value
-        #
-    @property
-    def upper_constraint(self) -> float:#-------------------------------------------------
-        ''' returns UpperContraint value'''
-        return self._parameter.UpperConstraint
-        #
-    @upper_constraint.setter
-    def upper_constraint(self, upper_contraint_value:float):#-----------------------------
-        ''' sets UpperContraint value'''
-        if not isinstance(upper_contraint_value, float) and  not isinstance(upper_contraint_value, int):
-            raise TypeError('upper_contraint_value must be float or int')
-        #end if
-        self._parameter.UpperConstraint = upper_contraint_value
-        #
-    @property
-    def step_size(self) -> float:#-------------------------------------------------
-        ''' returns StepSize value'''
-        return self._parameter.StepSize
-        #
-    @step_size.setter
-    def step_size(self, step_size_value:float):#-----------------------------
-        ''' sets StepSize value'''
-        if not isinstance(step_size_value, float) and  not isinstance(step_size_value, int):
-            raise TypeError('step_size_value must be float or int')
-        #end if
-        self._parameter.StepSize = step_size_value
-        #    
+
+
 class _Parameters():
-    def __init__(self, element, document_type):#----------------------------------------------
+    def __init__(self, element, document_type):
         self._element = element
         self._document_type = document_type
 
@@ -260,24 +98,12 @@ class _Elements():
 
     def _build_elements_dict(self):
         self._elements_dict = {}
-        if self._document_type == 'Global Definition':
-            for element in self._document.DataElements:
-                try:
-                    self._elements_dict[element.Name] = _Element(self._document.DataElements(element.Name), self._document_type)
-                except:
-                    raise RuntimeError('Failed to create dictionary of Elements')
-                #end try
-            #end for
-        else:
-            for element in self._document.Elements:
-                try:
-                    self._elements_dict[element.Name] = _Element(self._document.Elements(element.Name), self._document_type)
-                except:
-                    raise RuntimeError('Failed to create dictionary of Elements')
-                #end try
-            #end for
-        #end if
-        #
+        for element in self._document.Elements:
+            try:
+                self._elements_dict[element.Name] = _Element(self._document.Elements(element.Name), self._document_type)
+            except:
+                raise RuntimeError('Failed to create dictionary of Elements')
+
     @property
     def elements_dict(self) -> dict:
         return self._elements_dict
@@ -297,18 +123,15 @@ class _Elements():
                    Each item in the list is an element name
         '''
         elements_list = list()
-        if self._document_type == 'Global Definition':
-            for element in self._document.DataElements:
-                elements_list.append(element.Name)
-            #end for
-        else:
-            for element in self._document.Elements:
-                elements_list.append(element.Name)
-            #end for
-        #end if
+        for element in self._document.Elements:
+            elements_list.append(element.Name)
+
         return elements_list
 
     def add_element(self, element_name, x_pos: float, y_pos: float, rotation: float=0, flipped: bool=False):
+
+        #TODO!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        #
         '''
         Add an element to the document
         
@@ -328,26 +151,12 @@ class _Elements():
         none
                     
         '''          
-        if not isinstance(element_name, str):
-            raise TypeError('element_name must be string type')
-        if not (isinstance(x_pos, float) or isinstance(x_pos, int)):
-            raise TypeError('x_pos must be float or int type')
-        if not (isinstance(y_pos, float) or isinstance(y_pos, int)):
-            raise TypeError('y_pos must be float or int type')
-        if not (isinstance(rotation, float) or isinstance(rotation, int)):
-            raise TypeError('rotation must be float or int type') 
-        if not isinstance(flipped, bool):
-            raise TypeError('flipped must be bool type')
-        #end if
-        #
-        try:
-            new_element = self._document.Elements.Add(element_name, x_pos, y_pos, rotation, flipped)
-            self._elements_dict[new_element.Name] = _Element(self._document.Elements(new_element.Name), self._document_type)
-        except:
-            raise RuntimeError('Error when adding element: '+element_name)
-        #end try
+        pass
         #
     def remove_element(self, element_name_n_id: str) -> bool:#-----------------------------------------
+        #
+        #TODO!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        #
         '''
         Delete an element from the document
         
@@ -364,23 +173,7 @@ class _Elements():
                     False if element could not be deleted
                     
         '''          
-        if not isinstance(element_name_n_id, str):
-            raise TypeError('element_name_n_id must be a string')
-        #end if
-        element_removed = False
-        try:
-            for ele_idx in range(self._document.Elements.Count):
-                if self._document.Elements[ele_idx].Name == element_name_n_id:
-                    self._document.Elements.Remove(ele_idx+1)
-                    element_removed = True
-                    self._elements_dict.pop(element_name_n_id)
-                    break
-                #end if
-            #end for
-        except:
-            warnings.warn('remove_element: Element ' + element_name_n_id + ' did not get removed')
-        #end try
-        return element_removed
+        pass
         #
 #
 #**********************************************************************************************
@@ -393,49 +186,6 @@ class _Element(_Parameters):
         #
     def set_optimization(self, optimization_bounds: np.ndarray ) -> bool:
         pass
-        #
-    @property
-    def element_name(self) -> str: #------------------------------------------
-        '''returns element name'''
-        return self._element.Name
-        #    
-    @property
-    def xy_position(self) -> tuple:#-------------------------------------------------
-        x_position = self._element.x
-        y_position = self._element.y
-        xy_position_tuple = (x_position, y_position)
-        return xy_position_tuple
-        #    
-    def set_xy_position(self, xy_position_tuple: tuple):#------------------------------
-        '''set xy position'''
-        self._element.x = xy_position_tuple[0]
-        self._element.y = xy_position_tuple[1]
-        #
-    def element_enable(self):#------------------------------------------------------
-        self._element.Enabled = True
-        #
-    def element_disable(self):#------------------------------------------------------
-        self._element.Enabled = False
-        #    
-    @property
-    def element_nodes_dict(self) -> dict:#--------------------------------------------------------
-        ''' 
-        returns dictionary of node x,y values
-        
-        Returns
-        -------
-             nodes_dict: dictionary 
-                         dictionary keys are the node numbers
-                         dictionary values are tuples with x,y values of the node
-        '''
-        nodes_dict = dict()
-        num_nodes = self._element.Nodes.Count
-        for node_idx in range(num_nodes):
-            nodes_dict[node_idx] = (self._element.Nodes[node_idx].x, self._element.Nodes[node_idx].y)
-        #end for
-        return nodes_dict
-        #
-    
 #
 #**********************************************************************************************
 #
@@ -627,17 +377,6 @@ class _Equation():
         '''returns equation name'''
         return self._equation_name
         #
-    @property
-    def equation_enabled(self) -> bool:#------------------------------------------
-        return self._eqn_doc.Equations(self._eqn_index).Enabled
-        #
-    @equation_enabled.setter
-    def equation_enabled(self, enabled_state: bool):#--------------------------
-        if not isinstance(enabled_state, bool):
-            raise TypeError('enabled_state must be boolean type')
-        #end if
-        self._eqn_doc.Equations(self._eqn_index).Enabled = enabled_state
-        #
     @equation_name.setter
     def equation_name(self, equation_name: str):
         '''modify equation name'''
@@ -704,65 +443,6 @@ class _Equation():
         self._eqn_doc.Equations(self._eqn_index).x = xy_position_tuple[0]
         self._eqn_doc.Equations(self._eqn_index).y = xy_position_tuple[1]
         #
-    @property
-    def optimize_enabled(self) -> bool:#----------------------------------------------
-        '''returns Optimize enabled state '''
-        return self._eqn_doc.Equations(self._eqn_index).Optimize
-        #
-    @optimize_enabled.setter
-    def optimize_enabled(self, enabled: bool):#--------------------------------------
-        '''sets Optimize enabled state '''
-        self._eqn_doc.Equations(self._eqn_index).Optimize = enabled
-        #
-    @property
-    def constrain(self) -> bool:#-------------------------------------------------------
-        '''returns Contrain enabled state '''
-        return self._eqn_doc.Equations(self._eqn_index).Constrain
-        #
-    @constrain.setter
-    def constrain(self, enabled: bool):#----------------------------------------------------
-        '''sets Contrain enabled state '''
-        self._eqn_doc.Equations(self._eqn_index).Constrain = enabled
-        #    
-    @property
-    def lower_constraint(self) -> float:#-------------------------------------------------
-        ''' returns LowerContraint value'''
-        return self._eqn_doc.Equations(self._eqn_index).LowerConstraint
-        #
-    @lower_constraint.setter
-    def lower_constraint(self, lower_contraint_value:float):#-----------------------------
-        ''' sets LowerContraint value'''
-        if not isinstance(lower_contraint_value, float) and  not isinstance(lower_contraint_value, int):
-            raise TypeError('lower_contraint_value must be float or int')
-        #end if
-        self._eqn_doc.Equations(self._eqn_index).LowerConstraint = lower_contraint_value
-        # 
-    @property
-    def upper_constraint(self) -> float:#-------------------------------------------------
-        ''' returns UpperContraint value'''
-        return self._eqn_doc.Equations(self._eqn_index).UpperConstraint
-        #
-    @upper_constraint.setter
-    def upper_constraint(self, upper_contraint_value:float):#-----------------------------
-        ''' sets UpperContraint value'''
-        if not isinstance(upper_contraint_value, float) and  not isinstance(upper_contraint_value, int):
-            raise TypeError('upper_contraint_value must be float or int')
-        #end if
-        self._eqn_doc.Equations(self._eqn_index).UpperConstraint = upper_contraint_value
-        #
-    @property
-    def step_size(self) -> float:#-------------------------------------------------
-        ''' returns StepSize value'''
-        return self._eqn_doc.Equations(self._eqn_index).StepSize
-        #
-    @step_size.setter
-    def step_size(self, step_size_value:float):#-----------------------------
-        ''' sets StepSize value'''
-        if not isinstance(step_size_value, float) and  not isinstance(step_size_value, int):
-            raise TypeError('step_size_value must be float or int')
-        #end if
-        self._eqn_doc.Equations(self._eqn_index).StepSize = step_size_value
-        #        
     def _update_equation(self):#---------------------------------------------------------
         '''write equation to AWR document'''
         variable_sign_dict = {'Variable definition':' = ', 'Parameter definition':' << ', 'Display value':':'}
